Calculates the monetary value of one micromort based on the Value of a Statistical Life (VSL).
See also
Other conversion:
as_microlife(),
as_micromort(),
as_probability(),
lle()
Calculates the monetary value of one micromort based on the Value of a Statistical Life (VSL).
Other conversion:
as_microlife(),
as_micromort(),
as_probability(),
lle()